@@ -27,12 +27,18 @@ __all__ = [
 
 def get_txt_dnspython(name, timeout=5):
     """Return a TXT record associated with a DNS name."""
+    import dkim
     try:
       a = dns.resolver.query(name, dns.rdatatype.TXT,raise_on_no_answer=False, lifetime=timeout)
       for r in a.response.answer:
           if r.rdtype == dns.rdatatype.TXT:
               return b"".join(list(r.items)[0].strings)
     except dns.resolver.NXDOMAIN: pass
+    except dns.resolver.NoNameservers: pass
+    except dns.resolver.NoResolverConfiguration as e:
+        raise dkim.DnsTimeoutError('dns.resolver.NoResolverConfiguration: {0}'.format(e))
+    except dns.exception.Timeout as e:
+        raise dkim.DnsTimeoutError('dns.exception.Timeout: {0}'.format(e))
     return None
 
 
